@@ -17,7 +17,7 @@ def writeChannels(chanInfo, bak=backUpVals):
             if 'value' not in chanInfo['channels'][ch]:
                 raise RuntimeError('No value found for ' + ch)
 
-    discardBak = []  # caput used in this function do not need to save backUps
+    discardBak = {}  # caput used in this function do not need to save backUps
     kwargs = {'bak': discardBak}
     for ch in chanInfo['channels']:
         for arg in ['wait', 'timeout']:
@@ -95,7 +95,7 @@ def writeChannels(chanInfo, bak=backUpVals):
 
 
 def restoreGroup(bakVal):
-    writeChannels(chanInfo=bakVal['value'], bak=[])
+    writeChannels(chanInfo=bakVal['value'], bak={})
 
 
 restoreMethods['group'] = restoreGroup
